package java.time.temporal;

import java.time.DayOfWeek;
import java.util.Objects;
import java.time.LocalDate;
import java.util.function.UnaryOperator;

public final class TemporalAdjusters
{
    private TemporalAdjusters() {
    }
    
    public static TemporalAdjuster ofDateAdjuster(UnaryOperator<LocalDate> obj) {
        Objects.requireNonNull(obj, "dateBasedAdjuster");
        return temporal2/* java.time.temporal.Temporal, */ -> temporal2.with((LocalDate)p0.apply(LocalDate.from(temporal2)));
    }
    
    public static TemporalAdjuster firstDayOfMonth() {
        return temporal/* java.time.temporal.Temporal, */ -> temporal.with(ChronoField.DAY_OF_MONTH, 1L);
    }
    
    public static TemporalAdjuster lastDayOfMonth() {
        return temporal/* java.time.temporal.Temporal, */ -> temporal.with(ChronoField.DAY_OF_MONTH, temporal.range(ChronoField.DAY_OF_MONTH).getMaximum());
    }
    
    public static TemporalAdjuster firstDayOfNextMonth() {
        return temporal/* java.time.temporal.Temporal, */ -> temporal.with(ChronoField.DAY_OF_MONTH, 1L).plus(1L, ChronoUnit.MONTHS);
    }
    
    public static TemporalAdjuster firstDayOfYear() {
        return temporal/* java.time.temporal.Temporal, */ -> temporal.with(ChronoField.DAY_OF_YEAR, 1L);
    }
    
    public static TemporalAdjuster lastDayOfYear() {
        return temporal/* java.time.temporal.Temporal, */ -> temporal.with(ChronoField.DAY_OF_YEAR, temporal.range(ChronoField.DAY_OF_YEAR).getMaximum());
    }
    
    public static TemporalAdjuster firstDayOfNextYear() {
        return temporal/* java.time.temporal.Temporal, */ -> temporal.with(ChronoField.DAY_OF_YEAR, 1L).plus(1L, ChronoUnit.YEARS);
    }
    
    public static TemporalAdjuster firstInMonth(DayOfWeek dayOfWeek) {
        return dayOfWeekInMonth(1, dayOfWeek);
    }
    
    public static TemporalAdjuster lastInMonth(DayOfWeek dayOfWeek) {
        return dayOfWeekInMonth(-1, dayOfWeek);
    }
    
    public static TemporalAdjuster dayOfWeekInMonth(int n, DayOfWeek obj) {
        Objects.requireNonNull(obj, "dayOfWeek");
        obj.getValue();
        if (n >= 0) {
            return temporal5/* java.time.temporal.Temporal, */ -> {
                Temporal temporal6 = temporal5.with(ChronoField.DAY_OF_MONTH, 1L);
                return temporal6.plus((long)(int)((long)((var_2_0B - temporal6.get(ChronoField.DAY_OF_WEEK) + 7) % 7) + ((long)p0 - 1L) * 7L), ChronoUnit.DAYS);
            };
        }
        return temporal2/* java.time.temporal.Temporal, */ -> {
            Temporal temporal3 = temporal2.with(ChronoField.DAY_OF_MONTH, temporal2.range(ChronoField.DAY_OF_MONTH).getMaximum());
            int n2 = var_2_0B - temporal3.get(ChronoField.DAY_OF_WEEK);
            return temporal3.plus((long)(int)((long)((n2 == 0) ? 0 : ((n2 > 0) ? (n2 - 7) : n2)) - ((long)(-p0) - 1L) * 7L), ChronoUnit.DAYS);
        };
    }
    
    public static TemporalAdjuster next(DayOfWeek dayOfWeek) {
        return temporal2/* java.time.temporal.Temporal, */ -> {
            dayOfWeek2.getValue();
            int n2 = temporal2.get(ChronoField.DAY_OF_WEEK) - n;
            return temporal2.plus((n2 >= 0) ? ((long)(7 - n2)) : ((long)(-n2)), ChronoUnit.DAYS);
        };
    }
    
    public static TemporalAdjuster nextOrSame(DayOfWeek dayOfWeek) {
        return temporal2/* java.time.temporal.Temporal, */ -> {
            dayOfWeek2.getValue();
            int n2 = temporal2.get(ChronoField.DAY_OF_WEEK);
            if (n2 == n) {
                return temporal2;
            }
            int n3;
            return temporal2.plus((n3 >= 0) ? ((long)(7 - n3)) : ((long)(-n3)), ChronoUnit.DAYS);
        };
    }
    
    public static TemporalAdjuster previous(DayOfWeek dayOfWeek) {
        return temporal2/* java.time.temporal.Temporal, */ -> {
            dayOfWeek2.getValue();
            int n2 = n - temporal2.get(ChronoField.DAY_OF_WEEK);
            return temporal2.minus((n2 >= 0) ? ((long)(7 - n2)) : ((long)(-n2)), ChronoUnit.DAYS);
        };
    }
    
    public static TemporalAdjuster previousOrSame(DayOfWeek dayOfWeek) {
        return temporal2/* java.time.temporal.Temporal, */ -> {
            dayOfWeek2.getValue();
            int n2 = temporal2.get(ChronoField.DAY_OF_WEEK);
            if (n2 == n) {
                return temporal2;
            }
            int n3;
            return temporal2.minus((n3 >= 0) ? ((long)(7 - n3)) : ((long)(-n3)), ChronoUnit.DAYS);
        };
    }
}
